@@ -4,6 +4,7 @@
 import os
 import sys
 import pickle
+from fileinit import fileinit
 
 # 入力を得る (マスターから受け取る) [mult]
 def get_input():
@@ -19,10 +20,12 @@ def get_input():
 def send_output(output_obj):
 	# ジョブ識別記号
 	job_id = sys.argv[1]
-	# 出力を書き込み (一時ファイル)
-	temporary_output_filename = "./__mult_temp_data__/_writing_output_%s.pickle"%job_id
-	with open(temporary_output_filename, "wb") as f:
-		pickle.dump(output_obj, f)
-	# 一時ファイルを本ファイルに改名 (書き込みの途上でmasterプロセスが読み込み始めないようにする処置)
+	# 書き込み中ファイルを作成
+	in_progress_filename = "./__mult_temp_data__/_writing_in_progress_%s"%job_id
+	fileinit(in_progress_filename, overwrite = True)
+	# 出力を書き込み
 	output_filename = "./__mult_temp_data__/output_%s.pickle"%job_id
-	os.rename(temporary_output_filename, output_filename)
+	with open(output_filename, "wb") as f:
+		pickle.dump(output_obj, f)
+	# 書き込み中ファイルを削除 (書き込みの途上でmasterプロセスが読み込み始めないようにする処置)
+	os.remove(in_progress_filename)
